pokesim
=======

This package contains a playable pokemon battle simulation game.
Currently supports only a small part of one Pokemon's moveset. Aims for
Gen VII compatibility; future generations are not guaranteed to be
playable. Also will not feature Mega Evolutions or Z-Moves for the
forseeable future. Double, Triple, Rotation and other misc. battle types
are a huge stretch goal, behind supporting multi-Pokemon teams.

Installation
------------

The easiest way to install is with ``pip``. If your pip installs for
python 3.6+, simply enter

::

    pip install pokesim

at the command line. To install manually, download this repo and run

::

    python setup.py install

Usage
-----

Once installed, you can just run ``pokesim``. The features currently
supported are below:

Supported Pokemon
~~~~~~~~~~~~~~~~~

-  Bulbasaur

Supported Moves
~~~~~~~~~~~~~~~

-  Amnesia
-  Double Team
-  Growl
-  Razor Leaf
-  Seed Bomb
-  Sweet Scent
-  Tackle
-  Vine Whip
-  Work Up

Missing Mechanics
~~~~~~~~~~~~~~~~~

The following mechanics have yet to be added.

-  Weather
-  Status-Effect moves (e.g. Confuse Ray, Fire Fang)
-  Priority moves (e.g. Quick Attack, Extremespeed)
-  Most other things tbh
-  Abilities
-  Hyper/Reverse Mode(s) (idk which I'll pick)
